"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AnimatedGallery = void 0;
var React = require("react");
var react_native_1 = require("react-native");
var ZoomView_1 = require("./ZoomView");
var _a = react_native_1.Dimensions.get("screen"), width = _a.width, height = _a.height;
var AnimatedGallery = function (props) {
    /**
     * Props recived by animated gallery
     */
    var imageUrls = props.imageUrls, spacing = props.spacing, thumbBorderWidth = props.thumbBorderWidth, thumbBorderColor = props.thumbBorderColor, imageSize = props.imageSize, renderLoader = props.renderLoader, disablefullScreen = props.disablefullScreen, backgroundColor = props.backgroundColor, onEndReached = props.onEndReached, invertThumbDirection = props.invertThumbDirection, invertGalleryDirection = props.invertGalleryDirection, _a = props.activeIndex, _activeIndex = _a === void 0 ? 0 : _a;
    /**
     * Refs for handling the communication between two FlatList
     */
    var topRef = React.useRef();
    var thumbRef = React.useRef();
    var _b = React.useState(1), zoomLevel = _b[0], setZoomLevel = _b[1];
    /**
     * Local state to keep the images array recevied as props
     */
    var _c = React.useState(null), images = _c[0], setImgaes = _c[1];
    /**
     * active index Keeps track of the selected index or active index
     */
    var _d = React.useState(_activeIndex), activeIndex = _d[0], setActiveIndex = _d[1];
    /**
     * If props are present then value from the props are applied else default value
     */
    var IMAGE_SIZE = imageSize ? imageSize : 80;
    var SPACING = spacing ? spacing : 10;
    var thumb_BORDER_WIDTH = thumbBorderWidth ? thumbBorderWidth : 2;
    var thumb_BORDER_COLOR = thumbBorderColor ? thumbBorderColor : "#ffff";
    var BACKGROUND_COLOR = backgroundColor ? backgroundColor : "#0000";
    /**
     * when the compoent mounts the value from the imageUrl props is locally saved to images state
     */
    React.useEffect(function () {
        if (imageUrls.length !== 0) {
            setImgaes(imageUrls);
        }
    }, [imageUrls]);
    /**
      Scroll to active index accepts index of the curent position as argument and onPress of the thumbNail
      parent flatlist item will be pushed to the current screnn by calculating the offset value to which the rendered item need to be moved
  
    */
    var scrollToActiveIndex = function (index, animated) {
        var _a, _b, _c;
        if (animated === void 0) { animated = true; }
        setActiveIndex(index);
        //@ts-ignore
        (_a = topRef === null || topRef === void 0 ? void 0 : topRef.current) === null || _a === void 0 ? void 0 : _a.scrollToOffset({
            offset: index * width,
            animated: animated,
        });
        if (index * (IMAGE_SIZE + SPACING) - IMAGE_SIZE / 2 > width / 2) {
            //@ts-ignore
            (_b = thumbRef === null || thumbRef === void 0 ? void 0 : thumbRef.current) === null || _b === void 0 ? void 0 : _b.scrollToOffset({
                offset: index * (IMAGE_SIZE + SPACING) - width / 2 + IMAGE_SIZE / 2,
                animated: animated,
            });
        }
        else {
            //@ts-ignore
            (_c = thumbRef === null || thumbRef === void 0 ? void 0 : thumbRef.current) === null || _c === void 0 ? void 0 : _c.scrollToOffset({
                offset: 0,
                animated: animated,
            });
        }
    };
    /**
     * Renders the custom loader if present
     */
    if (!images) {
        if (renderLoader) {
            return renderLoader;
        }
        else {
            return (<react_native_1.View style={{ justifyContent: "center", alignItems: "center", flex: 1 }}>
          <react_native_1.Text>Loading...</react_native_1.Text>
        </react_native_1.View>);
        }
    }
    /**
     * Renders the main component
     */
    return (<react_native_1.View style={{ flex: 1, backgroundColor: BACKGROUND_COLOR }}>
      <react_native_1.FlatList 
    //@ts-ignore
    ref={topRef} data={images} keyExtractor={function (item) { return item.id.toString(); }} horizontal pagingEnabled showsVerticalScrollIndicator={false} showsHorizontalScrollIndicator={false} inverted={invertGalleryDirection} scrollEnabled={zoomLevel === 1} onMomentumScrollEnd={function (e) {
            scrollToActiveIndex(Math.floor(e.nativeEvent.contentOffset.x / width));
        }} onContentSizeChange={function () {
            if (_activeIndex) {
                scrollToActiveIndex(_activeIndex, false);
            }
        }} renderItem={function (_a) {
            var item = _a.item;
            return (<react_native_1.View style={{ width: width, height: height }}>
              <react_native_1.View style={disablefullScreen
                    ? {
                        width: width,
                        height: height,
                        alignSelf: "center",
                        justifyContent: "center",
                    }
                    : [react_native_1.StyleSheet.absoluteFillObject]}>
                <ZoomView_1.default imageWidth={width} imageUrl={item.url} onZoom={setZoomLevel}/>
              </react_native_1.View>
            </react_native_1.View>);
        }}/>

      <react_native_1.FlatList data={images} 
    //@ts-ignore
    ref={thumbRef} keyExtractor={function (item) { return item.id.toString(); }} horizontal pagingEnabled showsHorizontalScrollIndicator={false} onEndReached={onEndReached} inverted={invertThumbDirection} contentContainerStyle={{ paddingHorizontal: SPACING }} style={{ position: "absolute", bottom: IMAGE_SIZE }} renderItem={function (_a) {
            var item = _a.item, index = _a.index;
            return (<react_native_1.TouchableOpacity onPress={function () { return scrollToActiveIndex(index); }}>
              <react_native_1.Image source={{ uri: item.url }} style={[
                    {
                        width: IMAGE_SIZE,
                        height: IMAGE_SIZE,
                        borderRadius: 12,
                        marginRight: SPACING,
                        borderWidth: thumb_BORDER_WIDTH,
                        borderColor: activeIndex === index ? thumb_BORDER_COLOR : "transparent",
                    },
                ]}/>
            </react_native_1.TouchableOpacity>);
        }}/>
    </react_native_1.View>);
};
exports.AnimatedGallery = AnimatedGallery;
//# sourceMappingURL=AnimatedGallery.js.map